utils::globalVariables(c(".", "x", "y", "label"))

#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end
#' trelliscopejs
#'
#' Create interactive Trelliscope displays
#'
#' \url{https://hafen.github.io/trelliscopejs/}
#'
#' @name trelliscopejs-package
#' @examples
#' help(package = trelliscopejs)
NULL

#' Labels for ggplot2 "mpg" data
#'
"mpg_labels"
